==> asksuite-core-2.32.8.tgz: package/services/SophiaAccessor.js <==
const request = require('request');
const FallbackResolver = require('../util/FallbackResolver');
const RequestPreprocessor = require('../util/RequestPreprocessor');
const { ErrorHandlerService } = require('./ErrorHandlerService');
const URLRegex =
  /^[(http(s)?):\/\/(www\.)?a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#?&//=]*)$/gi;

class SophiaAccessor {
  constructor(baseUrl, enabled, corePayload) {
    this.baseUrl = baseUrl;
    this.enabled = !!enabled;
    this.corePayload = corePayload;
  }

  resolveText(request) {
    console.log('[SophiaAccessor.resolveText started]');
    return new Promise((resolve) => {
      const defaultIntent = FallbackResolver.fallbackWithDefaultIntent(request.intents) || {};

      if (!this.enabled) {
        console.warn('[SophiaAccessor disabled]');
        resolve(defaultIntent);
        return;
      }

      const executor = async () => {
        const cleanText = RequestPreprocessor.removeUtilityTexts(
          RequestPreprocessor.removeEmoji(request.text),
        ).trim();
        const companyId = this.parseCompanyId(request.companyId);
        if (this.isNotUnderstandable(cleanText)) {
          defaultIntent.processingStep = {
            fallbackReason: 'text_not_understandable',
            intentFound: 'naoentendi',
            text: cleanText || '',
          };
          resolve(defaultIntent);
          return;
        }

        try {
          const result = await this.requestData(this.baseUrl, {
            message: request.text,
            companyId,
            language: request.language,
            conversationId: (this.corePayload || {}).conversationId,
          });
          console.log('[SophiaAccessor result]', result);
          const textResponse = result.response || '';
          console.log('[SophiaAccessor textResponse]', textResponse);

          const generateDialog = this.generateDialog(companyId, textResponse);
          resolve({
            ...generateDialog,
            processingStep: {
              fallbackReason: null,
              intentFound: generateDialog.intent,
              extraInfo: result.body.usage || null,
              text: cleanText || '',
              answer: textResponse || '',
            },
          });
        } catch (e) {
          console.error('[SophiaAccessor error]', e);
          const errorData = ErrorHandlerService.accessorErrorHandler(e);
          defaultIntent.processingStep = {
            fallbackReason: 'intent_not_found',
            intentFound: null,
            errorData,
          };
          resolve(defaultIntent);
        }
      };

      executor().then();
    });
  }

  requestData(url, json) {
    return new Promise((resolve, reject) => {
      request.post(url, { json }, (err, res) => {
        if (err) {
          reject(err);
        }
        resolve(res);
      });
    });
  }

  parseCompanyId(name) {
    let companyId = name;
    if (companyId.indexOf('.') > -1) {
      const splited = companyId.split('.');
      companyId = splited[splited.length - 1];
    }
    return companyId;
  }

  generateDialog(companyId, text) {
    return {
      intent: 'openai',
      dialog: `${companyId}.openai`,
      value: this.clearResponse(text),
      type: 'text',
      goToDialog: `${companyId}.encerramento`,
    };
  }

  clearResponse(text) {
    if (text.startsWith('Resposta:')) {
      return text.substr(10);
    }
    return text;
  }

  textToKeyword(text = '') {
    return text
      .toLowerCase()
      .normalize('NFD')
      .replace(/[^a-z]/g, '');
  }

  isNotUnderstandable(cleanText) {
    return (
      !cleanText || // empty string
      !/\w/gi.test(cleanText) || // Only special chars
      !/\D/gi.test(cleanText) || // Only digits
      URLRegex.test(cleanText) // Only link
    );
  }
}

module.exports = SophiaAccessor;

==> asksuite-core-2.32.9.tgz: package/services/SophiaAccessor.js <==
const request = require('request');
const FallbackResolver = require('../util/FallbackResolver');
const RequestPreprocessor = require('../util/RequestPreprocessor');
const { ErrorHandlerService } = require('./ErrorHandlerService');
const URLRegex =
  /^[(http(s)?):\/\/(www\.)?a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#?&//=]*)$/gi;

class SophiaAccessor {
  constructor(baseUrl, enabled, corePayload) {
    this.baseUrl = baseUrl;
    this.enabled = !!enabled;
    this.corePayload = corePayload;
  }

  resolveText(request) {
    console.log('[SophiaAccessor.resolveText started]');
    return new Promise((resolve) => {
      const defaultIntent = FallbackResolver.fallbackWithDefaultIntent(request.intents) || {};

      if (!this.enabled) {
        console.warn('[SophiaAccessor disabled]');
        resolve(defaultIntent);
        return;
      }

      const executor = async () => {
        const cleanText = RequestPreprocessor.removeUtilityTexts(
          RequestPreprocessor.removeEmoji(request.text),
        ).trim();
        console.log("[SophiaAccessor cleanText]", cleanText);
        const companyId = this.parseCompanyId(request.companyId);
        const companyName = request.companyName;
        if (this.isNotUnderstandable(cleanText)) {
          defaultIntent.processingStep = {
            fallbackReason: 'text_not_understandable',
            intentFound: 'naoentendi',
            text: cleanText || '',
          };
          resolve(defaultIntent);
          return;
        }

        try {
          const payload = {
            message: request.text,
            companyId,
            language: request.language,
            threadId: request.conversationId,
            companies: [
              {
                companyId,
                companyName,
              },
            ],
          };

          console.log("[SophiaAccessor payload]", payload);

          const result = await this.requestData(this.baseUrl, payload);
          console.log('[SophiaAccessor result]', result);
          const textResponse = result.response || '';
          console.log('[SophiaAccessor textResponse]', textResponse);

          const generateDialog = this.generateDialog(companyId, textResponse);
          resolve({
            ...generateDialog,
            processingStep: {
              fallbackReason: null,
              intentFound: generateDialog.intent,
              extraInfo: result.body.usage || null,
              text: cleanText || '',
              answer: textResponse || '',
            },
          });
        } catch (e) {
          console.error('[SophiaAccessor error]', e);
          const errorData = ErrorHandlerService.accessorErrorHandler(e);
          defaultIntent.processingStep = {
            fallbackReason: 'intent_not_found',
            intentFound: null,
            errorData,
          };
          resolve(defaultIntent);
        }
      };

      executor().then();
    });
  }

  requestData(url, json) {
    return new Promise((resolve, reject) => {
      request.post(url, { json }, (err, res) => {
        if (err) {
          reject(err);
        }
        resolve(res);
      });
    });
  }

  parseCompanyId(name) {
    let companyId = name;
    if (companyId.indexOf('.') > -1) {
      const splited = companyId.split('.');
      companyId = splited[splited.length - 1];
    }
    return companyId;
  }

  generateDialog(companyId, text) {
    return {
      intent: 'openai',
      dialog: `${companyId}.openai`,
      value: this.clearResponse(text),
      type: 'text',
      goToDialog: `${companyId}.encerramento`,
    };
  }

  clearResponse(text) {
    if (text.startsWith('Resposta:')) {
      return text.substr(10);
    }
    return text;
  }

  textToKeyword(text = '') {
    return text
      .toLowerCase()
      .normalize('NFD')
      .replace(/[^a-z]/g, '');
  }

  isNotUnderstandable(cleanText) {
    return (
      !cleanText || // empty string
      !/\w/gi.test(cleanText) || // Only special chars
      !/\D/gi.test(cleanText) || // Only digits
      URLRegex.test(cleanText) // Only link
    );
  }
}

module.exports = SophiaAccessor;
